'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopNamespace(e) {
	if (e && e.__esModule) return e;
	var n = Object.create(null);
	if (e) {
		Object.keys(e).forEach(function (k) {
			if (k !== 'default') {
				var d = Object.getOwnPropertyDescriptor(e, k);
				Object.defineProperty(n, k, d.get ? d : {
					enumerable: true,
					get: function () { return e[k]; }
				});
			}
		});
	}
	n["default"] = e;
	return Object.freeze(n);
}

var React__namespace = /*#__PURE__*/_interopNamespace(React);

var classnames = {exports: {}};

/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/

(function (module) {
	/* global define */

	(function () {

		var hasOwn = {}.hasOwnProperty;

		function classNames() {
			var classes = [];

			for (var i = 0; i < arguments.length; i++) {
				var arg = arguments[i];
				if (!arg) continue;

				var argType = typeof arg;

				if (argType === 'string' || argType === 'number') {
					classes.push(arg);
				} else if (Array.isArray(arg)) {
					if (arg.length) {
						var inner = classNames.apply(null, arg);
						if (inner) {
							classes.push(inner);
						}
					}
				} else if (argType === 'object') {
					if (arg.toString === Object.prototype.toString) {
						for (var key in arg) {
							if (hasOwn.call(arg, key) && arg[key]) {
								classes.push(key);
							}
						}
					} else {
						classes.push(arg.toString());
					}
				}
			}

			return classes.join(' ');
		}

		if (module.exports) {
			classNames.default = classNames;
			module.exports = classNames;
		} else {
			window.classNames = classNames;
		}
	}());
} (classnames));

var classNames = classnames.exports;

var getDocumentFromRef = function (ref) {
    var _a;
    var _b = React__namespace.useState(false), isClient = _b[0], setIsClient = _b[1];
    React__namespace.useEffect(function () {
        setIsClient(true);
    });
    return isClient
        ? (_a = ref.current) === null || _a === void 0 ? void 0 : _a.ownerDocument
        : undefined;
};

var getWindow = function () {
    var _a = React__namespace.useState(false), isClient = _a[0], setIsClient = _a[1];
    React__namespace.useEffect(function () {
        setIsClient(true);
    });
    return isClient
        ? window
        : undefined;
};

function useControlled(_a) {
    var controlled = _a.controlled, defaultProp = _a["default"], name = _a.name, _b = _a.state, state = _b === void 0 ? 'value' : _b;
    var isControlled = React__namespace.useRef(controlled !== undefined).current;
    var _c = React__namespace.useState(defaultProp), valueState = _c[0], setValue = _c[1];
    var value = isControlled
        ? controlled
        : valueState;
    if (process.env.NODE_ENV !== 'production') {
        React__namespace.useEffect(function () {
            if (isControlled !== (controlled !== undefined)) {
                console.error([
                    "Styless: A component is changing the ".concat(isControlled ? '' : 'un', "controlled ").concat(state, " state of ").concat(name, " to be ").concat(isControlled ? 'un' : '', "controlled."),
                    'Elements should not switch from uncontrolled to controlled (or vice versa).',
                    "Decide between using a controlled or uncontrolled ".concat(name, " ") +
                        'element for the lifetime of the component.',
                    "The nature of the state is determined during the first render. It's considered controlled if the value is not `undefined`.",
                    'More info: https://fb.me/react-controlled-components',
                ].join('\n'));
            }
        }, [state, name, controlled]);
        var defaultValue_1 = React__namespace.useRef(defaultProp).current;
        React__namespace.useEffect(function () {
            if (!isControlled && defaultValue_1 !== defaultProp) {
                console.error([
                    "Styless: A component is changing the default ".concat(state, " state of an uncontrolled ").concat(name, " after being initialized. ") +
                        "To suppress this warning opt to use a controlled ".concat(name, "."),
                ].join('\n'));
            }
        }, [JSON.stringify(defaultProp)]);
    }
    var setValueIfUncontrolled = React__namespace.useCallback(function (newValue) {
        if (!isControlled) {
            setValue(newValue);
        }
    }, []);
    return [value, setValueIfUncontrolled];
}

var useCreateBlurHandler = function (disabled, onBlur) {
    return function (event) {
        if (disabled)
            return;
        onBlur === null || onBlur === void 0 ? void 0 : onBlur(event);
    };
};

var useCreateChangeHandler = function (disabled, onChange) {
    return function (event) {
        if (disabled)
            return;
        onChange === null || onChange === void 0 ? void 0 : onChange(event);
    };
};

var useCreateClickHandler = function (disabled, onClick) {
    return function (event) {
        if (disabled)
            return;
        onClick === null || onClick === void 0 ? void 0 : onClick(event);
    };
};

var useCreateFocusHandler = function (disabled, onFocus) {
    if (disabled === void 0) { disabled = false; }
    return function (event) {
        if (disabled)
            return;
        onFocus === null || onFocus === void 0 ? void 0 : onFocus(event);
    };
};

var useListFocusTrap = function (listLength, returnFocus, escapeKeyCode, firstKeyCode, lastKeyCode, nextKeyCode, previousKeyCode) {
    if (escapeKeyCode === void 0) { escapeKeyCode = 'escape'; }
    if (firstKeyCode === void 0) { firstKeyCode = 'home'; }
    if (lastKeyCode === void 0) { lastKeyCode = 'end'; }
    if (nextKeyCode === void 0) { nextKeyCode = 'ArrowDown'; }
    if (previousKeyCode === void 0) { previousKeyCode = 'ArrowUp'; }
    var _a = React__namespace.useState(false), isTrapped = _a[0], setIsTrapped = _a[1];
    var _b = React__namespace.useState(0), focusIndex = _b[0], setFocusIndex = _b[1];
    var _c = React__namespace.useState(0), previousFocusIndex = _c[0], setPreviousFocusIndex = _c[1];
    var handleKeyDown = function (event) {
        var lastFocusableIndex = listLength - 1;
        if (focusIndex) {
            setPreviousFocusIndex(focusIndex);
        }
        switch (event.code) {
            case escapeKeyCode:
                setIsTrapped(false);
                returnFocus();
                break;
            case firstKeyCode:
                setFocusIndex(0);
                break;
            case lastKeyCode:
                setFocusIndex(lastFocusableIndex);
                break;
            case nextKeyCode:
                if (focusIndex < lastFocusableIndex) {
                    setFocusIndex(focusIndex + 1);
                }
                else {
                    setFocusIndex(0);
                }
                break;
            case previousKeyCode:
                if (focusIndex === 0) {
                    setFocusIndex(lastFocusableIndex);
                }
                else {
                    setFocusIndex(focusIndex - 1);
                }
                break;
            default:
                if (isTrapped) {
                    event.preventDefault();
                }
                break;
        }
    };
    return {
        isTrapped: isTrapped,
        setIsTrapped: setIsTrapped,
        focusIndex: focusIndex,
        setFocusIndex: setFocusIndex,
        handleKeyDown: handleKeyDown,
        previousFocusIndex: previousFocusIndex,
        setPreviousFocusIndex: setPreviousFocusIndex
    };
};

var Accordion = React__namespace.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, _b = _a.disabled, disabled = _b === void 0 ? false : _b, onBlur = _a.onBlur, onClick = _a.onClick, onChange = _a.onChange, onFocus = _a.onFocus, onKeyDown = _a.onKeyDown, openProp = _a.open, title = _a.title;
    var id = React__namespace.useId();
    var _c = useControlled({
        controlled: openProp,
        "default": false,
        name: 'Accordion'
    }), open = _c[0], setOpenIfUncontrolled = _c[1];
    var button = React__namespace.useRef(null);
    React__namespace.useImperativeHandle(ref, function () {
        return {
            button: button.current,
            close: function () {
                setOpenIfUncontrolled(false);
                onChange === null || onChange === void 0 ? void 0 : onChange(false);
            },
            open: function () {
                setOpenIfUncontrolled(true);
                onChange === null || onChange === void 0 ? void 0 : onChange(false);
            }
        };
    }, [button]);
    React__namespace.useEffect(function () {
        onChange === null || onChange === void 0 ? void 0 : onChange(open || false);
    }, [open]);
    var handleBlur = useCreateBlurHandler(disabled, onBlur);
    var handleClick = useCreateClickHandler(disabled, function (event) {
        onClick === null || onClick === void 0 ? void 0 : onClick(event);
        setOpenIfUncontrolled(!open);
    });
    var handleFocus = useCreateFocusHandler(disabled, onFocus);
    var handleKeyDown = function (event) {
        if (disabled)
            return;
        onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(event);
    };
    return React__namespace.createElement(React__namespace.Fragment, null,
        React__namespace.createElement("button", { "aria-owns": "".concat(id, "-accordion-body"), className: classNames('accordion-header', className), onBlur: handleBlur, onClick: handleClick, onFocus: handleFocus, onKeyDown: handleKeyDown, ref: button }, title),
        React__namespace.createElement("div", { className: classNames('accordion-content', open ? 'visible' : 'hidden'), id: "".concat(id, "-accordion-body") }, children));
});
Accordion.displayName = 'Accordion';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var AccordionGroup = function (_a) {
    var children = _a.children;
    React__namespace.useRef(null);
    var returnFocus = function () {
    };
    var _b = useListFocusTrap(React__namespace.Children.count(children), returnFocus), isTrapped = _b.isTrapped, setIsTrapped = _b.setIsTrapped, focusIndex = _b.focusIndex, setFocusIndex = _b.setFocusIndex, handleKeyDown = _b.handleKeyDown, previousFocusIndex = _b.previousFocusIndex, setPreviousFocusIndex = _b.setPreviousFocusIndex;
    var activeAccordion = React__namespace.useRef(null);
    var previousAccordion = React__namespace.useRef(null);
    React__namespace.useEffect(function () {
        var _a, _b;
        if (isTrapped && activeAccordion.current !== null) {
            (_b = (_a = activeAccordion.current) === null || _a === void 0 ? void 0 : _a.button) === null || _b === void 0 ? void 0 : _b.focus();
        }
    }, [isTrapped]);
    React__namespace.useEffect(function () {
        var _a, _b;
        if (activeAccordion.current !== null) {
            (_b = (_a = activeAccordion.current) === null || _a === void 0 ? void 0 : _a.button) === null || _b === void 0 ? void 0 : _b.focus();
        }
    }, [focusIndex]);
    React__namespace.useEffect(function () {
        var _a;
        (_a = activeAccordion.current) === null || _a === void 0 ? void 0 : _a.open();
    }, [
        activeAccordion.current
    ]);
    React__namespace.useEffect(function () {
        var _a;
        (_a = previousAccordion.current) === null || _a === void 0 ? void 0 : _a.close();
    }, [
        previousAccordion.current
    ]);
    var handleOnAccordionClick = function (index) { return __awaiter(void 0, void 0, void 0, function () {
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!(focusIndex !== index)) return [3 /*break*/, 3];
                    return [4 /*yield*/, setPreviousFocusIndex(focusIndex)];
                case 1:
                    _a.sent();
                    return [4 /*yield*/, setFocusIndex(index)];
                case 2:
                    _a.sent();
                    _a.label = 3;
                case 3: return [2 /*return*/];
            }
        });
    }); };
    var handleAccordionGroupKeyDown = function (event) {
        switch (event.key) {
            case 'ArrowDown':
                setIsTrapped(true);
                break;
        }
    };
    return React__namespace.createElement("div", { onKeyDown: handleAccordionGroupKeyDown, tabIndex: 0 }, React__namespace.Children.map(children, function (child, index) {
        var assertedChild = child;
        return React__namespace.cloneElement(assertedChild, __assign(__assign(__assign(__assign({ key: assertedChild.props.title }, assertedChild.props), { onClick: function () {
                handleOnAccordionClick(index);
            }, onKeyDown: handleKeyDown }), (index === focusIndex && { ref: activeAccordion })), (index === previousFocusIndex && { ref: previousAccordion })));
    }));
};
AccordionGroup.displayName = 'AccordionGroup';

/**
 * Styless Link Component
 *
 * The link component renders an anchor element. The anchor element
 * has two variants associated with it: 'link' and 'button'. The link
 * variant is the default variant that will render.
 *
 * Usage:
 * <Link href='https://example.com'>
 *   Link Text
 * </Link>
 */
var Link = React__namespace.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, _b = _a.disabled, disabled = _b === void 0 ? false : _b, href = _a.href, onBlur = _a.onBlur, onClick = _a.onClick, onFocus = _a.onFocus, _c = _a.variant, variant = _c === void 0 ? 'link' : _c, props = __rest(_a, ["children", "className", "disabled", "href", "onBlur", "onClick", "onFocus", "variant"]);
    if (process.env.ENVIRONMENT !== 'production') {
        if (!href.startsWith('http://') || !href.startsWith('https://')) {
            console.error("\n                DS: links require their href prop to start with either http:// or https://.\n            ");
        }
    }
    var handleBlur = useCreateBlurHandler(disabled, onBlur);
    var handleClick = useCreateClickHandler(disabled, onClick);
    var handleFocus = useCreateFocusHandler(disabled, onFocus);
    return React__namespace.createElement("a", __assign({}, props, { className: classNames('link', variant, className), href: href, onBlur: handleBlur, onClick: handleClick, onFocus: handleFocus, ref: ref }), children);
});
Link.displayName = 'Link';

/**
 * Styless ListItem Component
 *
 * The list item component renders a li element. Its only purpose is
 * to provide all of the components you need to use the UnorderedList
 * and OrderedList components.
 */
var ListItem = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React__namespace.createElement("li", __assign({ className: classNames('list-item', className) }, props), children);
};
ListItem.displayName = 'ListItem';

/**
 * Styless OrderedList Component
 *
 * The styless ordered list component renders a ol element.
 *
 * Usage:
 * <OrderedList>
 *   <ListItem>one</ListItem>
 *   ...more list items
 * </OrderedList>
 */
var OrderedList = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React__namespace.createElement("ul", __assign({ className: classNames('ordered-list', className) }, props), children);
};
OrderedList.displayName = 'OrderedList';

var Breadcrumb = function (_a) {
    var className = _a.className, crumbs = _a.crumbs, id = _a.id;
    return React__namespace.createElement("nav", { "aria-label": 'Breadcrumbs navigation.', className: classNames('breadcrumbs', className), id: "".concat(id, "-breadcrumb-wrapper") },
        React__namespace.createElement(OrderedList, null, crumbs === null || crumbs === void 0 ? void 0 : crumbs.map(function (crumb, index) {
            return React__namespace.createElement(ListItem, { key: crumb.label },
                React__namespace.createElement(Link, { "aria-current": index === crumbs.length - 1, href: crumb.url }, crumb.label));
        })));
};
Breadcrumb.displayName = 'Breadcrumb';

/**
 * Styless Button Component
 *
 * The styless button component renders a button element. The button has a few
 * design system props that control how it renders. Color controls the theme
 * color of the button, size controls the size of the button, and variant controls
 * how it is rendered. The default color is 'primary', the default size is 'medium',
 * and the default variant is 'filled'. We also made the default value for prop 'button'.
 *
 * Usage:
 * <Button>
 *   Submit
 * </Button>
 */
var Button = React__namespace.forwardRef(function (_a, ref) {
    var children = _a.children, className = _a.className, _b = _a.color, color = _b === void 0 ? 'primary' : _b, _c = _a.disabled, disabled = _c === void 0 ? false : _c, _d = _a.fullWidth, fullWidth = _d === void 0 ? false : _d, onBlur = _a.onBlur, onClick = _a.onClick, onFocus = _a.onFocus, _e = _a.size, size = _e === void 0 ? 'medium' : _e, _f = _a.type, type = _f === void 0 ? 'button' : _f, _g = _a.variant, variant = _g === void 0 ? 'filled' : _g, props = __rest(_a, ["children", "className", "color", "disabled", "fullWidth", "onBlur", "onClick", "onFocus", "size", "type", "variant"]);
    var handleBlur = useCreateBlurHandler(disabled, onBlur);
    var handleClick = useCreateClickHandler(disabled, onClick);
    var handleFocus = useCreateFocusHandler(disabled, onFocus);
    return React__namespace.createElement("button", __assign({}, props, { className: classNames('button', color, fullWidth, size, variant, className), disabled: disabled, onBlur: handleBlur, onClick: handleClick, onFocus: handleFocus, type: type, ref: ref }), children);
});
Button.displayName = 'Button';

/**
 * Styless Card Component
 *
 * The styless card component renders an article element.
 *
 * Usage:
 * <Card>
 *   <Typography variant='h1'>
 *     Card Heading
 *   </Typography>
 *
 *   <Typography>
 *     Some card content.
 *   </Typography>
 *
 *   <Link href='/to/somewhere' aria-label='view more about the topic of this content'>
 *     View more
 *   </Link>
 * </Card>
 */
var Card = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React__namespace.createElement("article", __assign({ className: classNames('card', className) }, props), children);
};
Card.displayName = 'Card';

/**
 * Styless Error Component
 *
 * The styless error component renders a span element. The
 * error component is designed mainly for building out custom
 * input elements.
 */
var Error = function (_a) {
    var children = _a.children, id = _a.id;
    return React__namespace.createElement("span", { "aria-live": 'polite', id: id, role: 'region' }, children);
};
Error.displayName = 'Error';

/**
 * Styless Hint Component
 *
 * The styless hint component renders a span element. The
 * hint component is designed mainly for building out custom
 * input elements.
 */
var Hint = function (_a) {
    var children = _a.children, id = _a.id;
    return React__namespace.createElement("span", { id: id }, children);
};
Hint.displayName = 'Hint';

/**
 * Styless Input Component
 *
 * The styless input component contains the label, input, hint, and error component. This
 * is to make input elements ada-compliant by default. The hint and error components will
 * only render if you provide a value for their respective props. The usage example below
 * shows how to use an input that will have a hint and error component.
 *
 * Usage:
 * <Input
 *   error='Please enter a valid first name.'
 *   hint='Joe Smith'
 *   label='First Name'
 * />
 */
var Input = React__namespace.forwardRef(function (_a, ref) {
    var className = _a.className, defaultValue = _a.defaultValue, _b = _a.disabled, disabled = _b === void 0 ? false : _b, error = _a.error, hint = _a.hint, label = _a.label, name = _a.name, onBlur = _a.onBlur, onChange = _a.onChange, onFocus = _a.onFocus, placeholder = _a.placeholder, valueProp = _a.value; _a.variant; var props = __rest(_a, ["className", "defaultValue", "disabled", "error", "hint", "label", "name", "onBlur", "onChange", "onFocus", "placeholder", "value", "variant"]);
    var id = React__namespace.useId();
    var _d = useControlled({
        controlled: valueProp,
        "default": defaultValue,
        name: 'Input'
    }), value = _d[0], setValueIfUndefined = _d[1];
    var handleBlur = useCreateBlurHandler(disabled, onBlur);
    var handleChange = useCreateChangeHandler(disabled, function (event) {
        onChange === null || onChange === void 0 ? void 0 : onChange(event);
        setValueIfUndefined(event.currentTarget.value);
    });
    var handleFocus = useCreateFocusHandler(disabled, onFocus);
    return React__namespace.createElement(React__namespace.Fragment, null,
        React__namespace.createElement("label", { htmlFor: "".concat(id, "-input") },
            label,
            React__namespace.createElement("input", __assign({}, props, { "aria-describedby": "".concat(id, "-hint"), "aria-errormessage": "".concat(id, "-error"), "aria-invalid": !!error, className: classNames('input', className), id: "".concat(id, "-input"), name: name, onBlur: handleBlur, onChange: handleChange, onFocus: handleFocus, placeholder: placeholder, value: value, ref: ref }))),
        hint && React__namespace.createElement(Hint, { id: "".concat(id, "-hint") }, hint),
        error && React__namespace.createElement(Error, { id: "".concat(id, "-error") }, error));
});
Input.displayName = 'Input';

var Checkbox = React__namespace.forwardRef(function (props, ref) {
    return React__namespace.createElement(Input, __assign({}, props, { className: classNames('checkbox', props.className), type: 'email', ref: ref }));
});
Checkbox.displayName = 'Checkbox';

/**
 * Styless Code Component
 *
 * The styless code component renders a span that contains code within it
 * and a button for copying the code contained within that span.
 *
 * Usage:
 * <Code
 *   copyIcon={CopyIcon}
 *   id='my-code'
 * >
 *   {codeString}
 * </Code>
 */
var Code = function (_a) {
    var children = _a.children, className = _a.className, copyIcon = _a.copyIcon, id = _a.id, language = _a.language;
    var codeRef = React__namespace.useRef(null);
    var window = getWindow();
    var handleCopyClick = function () {
        var hasRef = !!codeRef.current;
        if (hasRef && !!window) {
            var code = codeRef.current.innerHTML;
            window.navigator.clipboard.writeText(code);
        }
    };
    return React__namespace.createElement("div", { className: classNames('code-root', className), id: "".concat(id, "-code-root") },
        React__namespace.createElement("div", { className: 'code-header', id: "".concat(id, "-code-header") },
            React__namespace.createElement("span", null, language),
            React__namespace.createElement("button", { className: 'code-copy-button', onClick: handleCopyClick }, copyIcon)),
        React__namespace.createElement("span", { className: 'code-content', id: "".concat(id, "-code-content"), ref: codeRef }, children));
};
Code.displayName = 'Code';

var Email = React__namespace.forwardRef(function (props, ref) {
    return React__namespace.createElement(Input, __assign({}, props, { className: classNames('email', props.className), type: 'email', ref: ref }));
});
Email.displayName = 'Email';

/**
 * Styless Fieldset Component
 *
 * The fieldset component renders a fieldset, legend, and children
 * passed to it. The legend prop controls the legend text that is
 * rendered.
 *
 * Usage:
 * <Fieldset legend='Personal Information'>
 *   <Input label='First Name' hint='Allison' />
 *   <Input label='Last Name' hint='Smith' />
 *   <Email label='Email' hint='example@example.com' />
 * </Fieldset>
 */
var Fieldset = function (_a) {
    var children = _a.children, className = _a.className, legend = _a.legend, props = __rest(_a, ["children", "className", "legend"]);
    return React__namespace.createElement("fieldset", __assign({}, props, { className: classNames('fieldset', className) }),
        React__namespace.createElement("legend", { className: 'fieldset-legend' }, legend),
        children);
};
Fieldset.displayName = 'Fieldset';

/**
 * Styless IconButton Component
 *
 * The icon button component renders our button component with icon rendering
 * capabilities. The icon is always rendered before the button text.
 *
 * Usage:
 * <IconButton icon={TrashIcon}>
 *   Delete
 * </IconButton>
 */
var IconButton = React__namespace.forwardRef(function (_a, ref) {
    var ariaLabel = _a["aria-label"], className = _a.className, icon = _a.icon, name = _a.name, props = __rest(_a, ['aria-label', "className", "icon", "name"]);
    return React__namespace.createElement(Button, __assign({}, props, { "aria-label": ariaLabel, className: classNames('icon-button', className), name: name, ref: ref }), icon);
});
IconButton.displayName = 'IconButton';

/**
 * Styless Image Component
 *
 * The styless image component renders a figure, figcaption, and img element. The alt
 * prop for the Image component is used as the alt attribute value on the img element
 * and as the child for the figcaption element. The width and the height is provided
 * for core web vitals performance.
 *
 * Usage:
 * <Image alt='some alt text' src='https://my-img-url' />
 */
var Image = function (_a) {
    var alt = _a.alt, className = _a.className, src = _a.src;
    return React__namespace.createElement("figure", { className: 'image-wrapper' },
        React__namespace.createElement("img", { alt: alt, className: classNames('image', className), src: src }),
        React__namespace.createElement("figcaption", { className: 'image-caption' }, alt));
};
Image.displayName = 'Image';

var Password = React__namespace.forwardRef(function (props, ref) {
    return React__namespace.createElement(Input, __assign({}, props, { className: classNames('password', props.className), type: 'password', ref: ref }));
});
Password.displayName = 'Password';

var Radio = React__namespace.forwardRef(function (props, ref) {
    return React__namespace.createElement(Input, __assign({}, props, { className: classNames('radio', props.className), type: 'email', ref: ref }));
});
Radio.displayName = 'Radio';

/**
 * The typography component renders the correct element based off of
 * the variant prop's value.
 *
 * Usage:
 * <Typography variant='h1'>
 *   Main Heading
 * </Typography>
 *
 * <Typography>
 *   Body text.
 * </Typography>
 */
var Typography = function (_a) {
    var children = _a.children, className = _a.className, _b = _a.variant, variant = _b === void 0 ? 'p' : _b, props = __rest(_a, ["children", "className", "variant"]);
    return React__namespace.createElement(variant, __assign(__assign({}, props), { className: classNames('typography', variant, className), role: variant === 'p' ? 'paragraph' : null }), children);
};
Typography.displayName = 'Typography';

/**
 * Styless UnorderedList Component
 *
 * The styless unordered list component renders a ul element.
 *
 * Usage:
 * <OrderedList>
 *   <ListItem>one</ListItem>
 *   ...more list items
 * </OrderedList>
 */
var UnorderedList = function (_a) {
    var children = _a.children, className = _a.className, props = __rest(_a, ["children", "className"]);
    return React__namespace.createElement("ul", __assign({ className: classNames('unordered-list', className) }, props), children);
};
UnorderedList.displayName = 'UnorderedList';

exports.Accordion = Accordion;
exports.AccordionGroup = AccordionGroup;
exports.Breadcrumb = Breadcrumb;
exports.Button = Button;
exports.Card = Card;
exports.Checkbox = Checkbox;
exports.Code = Code;
exports.Email = Email;
exports.Error = Error;
exports.Fieldset = Fieldset;
exports.Hint = Hint;
exports.IconButton = IconButton;
exports.Image = Image;
exports.Input = Input;
exports.Link = Link;
exports.ListItem = ListItem;
exports.OrderedList = OrderedList;
exports.Password = Password;
exports.Radio = Radio;
exports.Typography = Typography;
exports.UnorderedList = UnorderedList;
exports.getDocumentFromRef = getDocumentFromRef;
exports.getWindow = getWindow;
exports.useControlled = useControlled;
exports.useCreateBlurHandler = useCreateBlurHandler;
exports.useCreateChangeHandler = useCreateChangeHandler;
exports.useCreateClickHandler = useCreateClickHandler;
exports.useCreateFocusHandler = useCreateFocusHandler;
exports.useListFocusTrap = useListFocusTrap;
